import json

from magnifai_aut_sdk.aut_properties import AutProperties
from magnifai_aut_sdk.magnifai import Magnifai

EXECUTION = "64f720e2369a3e455f228d03"
AutProperties.load_property_file('config.ini')


def test_compare():
    excluded_areas = [
            {"topLeftX": 710, "topLeftY": 150, "bottomRightX": 830, "bottomRightY": 310},
            {"topLeftX": 200, "topLeftY": 300, "bottomRightX": 500, "bottomRightY": 450}
    ]

    rs = Magnifai.compare(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python compare',
                          baseline_image='tests/images/magnifai_base.png',
                          input_image='tests/images/magnifai_input.png',
                          min_similarity='90', excluded_areas=excluded_areas)
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Passed'


def test_compare_url():
    rs = Magnifai.compare(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python compare urls',
                          baseline_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                          input_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                          min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Passed'


def test_flex_compare():
    rs = Magnifai.compare(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python flex compare',
                          baseline_image='tests/images/magnifai_base.png',
                          input_image='tests/images/magnifai_input.png', min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Passed'


def test_flex_compare_url():
    rs = Magnifai.flex_compare(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python flex compare url',
                               baseline_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                               input_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                               min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Passed'


def test_search():
    rs = Magnifai.search(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search',
                         parent_image='tests/images/magnifai_base.png',
                         child_image='tests/images/magnifai_child.png', min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_search_url():
    rs = Magnifai.search(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search urls',
                         parent_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                         child_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                         min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_flex_search():
    rs = Magnifai.flex_search(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search',
                              parent_image='tests/images/magnifai_base.png',
                              child_image='tests/images/magnifai_child.png', min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_flex_search_url():
    rs = Magnifai.flex_search(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search urls',
                              parent_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                              child_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                              min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_locate():
    rs = Magnifai.locate(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search',
                         container_image='tests/images/magnifai_base.png',
                         main_image='tests/images/magnifai_main.png',
                         relative_image="tests/images/magnifai_relative.png",
                         min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_locate_url():
    rs = Magnifai.locate(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search urls',
                         container_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                         main_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                         relative_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                         min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_flex_locate():
    rs = Magnifai.flex_locate(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search',
                              container_image='tests/images/magnifai_base.png',
                              main_image='tests/images/magnifai_main.png',
                              relative_image="tests/images/magnifai_relative.png", min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'


def test_flex_locate_url():
    rs = Magnifai.flex_locate(execution_id=EXECUTION, test_name='test magnifai-aut-magnifai_aut_sdk-python search urls',
                              container_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                              main_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                              relative_image_url="https://upload.wikimedia.org/wikipedia/commons/b/b1/Mandriva_2009.1_KDE4.2_Bureau.png",
                              min_similarity='90')
    assert rs.status_code == 200
    response_json = json.loads(rs.text)
    assert response_json.get('status') == 'Found'



import configparser


class AutProperties:
    properties = {}

    def __init__(self):
        raise Exception("Utility class")

    @classmethod
    def reset_defaults(cls):
        cls.properties.clear()
        cls.set_property(Property.MAGNIFAI_HOST, "http://localhost")
        cls.set_property(Property.MAGNIFAI_AUTH_HOST, "http://localhost")
        cls.set_property(Property.AUTH_PORT, "8080")
        cls.set_property(Property.AUTH_TOKEN_THRESHOLD_SECONDS, "30")
        cls.set_property(Property.DASHBOARDAPI_PORT, "3274")
        cls.set_property(Property.ASSETS_PORT, "2773")
        cls.set_property(Property.METERING_PORT, "6383")
        cls.set_property(Property.MAGNIFAIAPI_PORT, "6246")

    @classmethod
    def load_property_file(cls, property_file_name):
        try:
            config = configparser.ConfigParser()
            config.read(property_file_name)
            cls.set_property(Property.MAGNIFAI_HOST, config['Global']['host'])
            cls.set_property(Property.MAGNIFAI_PORT, config['Global']['port'])
            cls.set_property(Property.MAGNIFAI_AUTH_HOST, config['Auth']['host'])
            cls.set_property(Property.AUTH_PORT, config['Auth']['port'])
            cls.set_property(Property.AUTH_USER, config['Auth']['user'])
            cls.set_property(Property.AUTH_PASSWORD, config['Auth']['password'])
            cls.set_property(Property.AUTH_TOKEN_THRESHOLD_SECONDS, config['Auth']['token.threshold.seconds'])
            cls.set_property(Property.DASHBOARDAPI_PORT, config['dashboard-api']['port'])
            cls.set_property(Property.ASSETS_PORT, config['assets-api']['port'])
            cls.set_property(Property.METERING_PORT, config['metering-api']['port'])
            cls.set_property(Property.MAGNIFAIAPI_PORT, config['magnifai-api']['port'])
        except:
            pass

    @classmethod
    def get_property(cls, key):
        return cls.properties.get(key)

    @classmethod
    def set_property(cls, key, value):
        cls.properties[key] = value

    @classmethod
    def set_common_port(cls, port):
        cls.set_property(Property.MAGNIFAI_PORT.getKey(), str(port))
        cls.properties.pop(Property.AUTH_PORT.getKey(), None)
        cls.properties.pop(Property.DASHBOARDAPI_PORT.getKey(), None)
        cls.properties.pop(Property.ASSETS_PORT.getKey(), None)
        cls.properties.pop(Property.MAGNIFAIAPI_PORT.getKey(), None)


class Property:
    MAGNIFAI_HOST = "magnifai.host"
    MAGNIFAI_AUTH_HOST = "magnifai_auth.host"
    MAGNIFAI_PORT = "magnifai.port"
    AUTH_PORT = "auth.port"
    AUTH_USER = "auth.user"
    AUTH_PASSWORD = "auth.password"
    AUTH_TOKEN_THRESHOLD_SECONDS = "auth.token.threshold.seconds"
    DASHBOARDAPI_PORT = "dashboardapi.port"
    ASSETS_PORT = "assets.port"
    METERING_PORT = "metering.port"
    MAGNIFAIAPI_PORT = "magnifaiapi.port"



import json
import mimetypes
import urllib.request

import requests

from magnifai_aut_sdk.aut_auth import AutAuth
from magnifai_aut_sdk.aut_properties import AutProperties, Property


class Magnifai:
    def __init__(self):
        pass

    @classmethod
    def base_request(cls, port, path, execution_id, test_name):
        base_uri = AutProperties.get_property(Property.MAGNIFAI_HOST)
        data = {
            "base_uri": base_uri,
            "port": port,
            "path": path,
            "auth": AutAuth.get_token(),
            "payload": {}
        }

        if execution_id:
            data["payload"]["executionId"] = execution_id
        if test_name:
            data["payload"]["testName"] = test_name
        return data

    @classmethod
    def compare(cls, execution_id, test_name, baseline_image=None, baseline_image_url=None, input_image=None,
                input_image_url=None, min_similarity='70', excluded_areas=None, noise_filter=0):
        """
            Compare the baselineImage with the inputImage and generate a resultImage highlighting the differences if any were found.
            The images must have the same dimensions. For further information, view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str baseline_image: Path to baseline image to compare with the input image.
            :param str baseline_image_url: Baseline image to compare with the inputImage from URL.
            :param str input_image: Path to input image to be compared with the baseline image.
            :param str input_image_url: Input image to be compared with the baselineImage from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :param list excluded_areas: Areas to be ignored when comparing the images.
                                        These areas are defined on the baseline image.
            :param int noise_filter: Areas to be ignored when comparing the images.
                                        These areas are defined on the baseline image.
            :return: The API Response object.
            :rtype: Response
        """

        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/image-comparison", execution_id,
                                test_name)
        data["files"] = []
        if baseline_image:
            data["files"].append(('baselineImage', (cls.get_input_name(baseline_image), open(
                baseline_image,
                'rb'), mimetypes.guess_type(input_image)[0])))

        if baseline_image_url:
            data['payload']["baselineImageUrl"] = baseline_image_url

        if input_image:
            data["files"].append(('inputImage', (cls.get_input_name(input_image), open(
                input_image,
                'rb'), mimetypes.guess_type(input_image)[0])))

        if input_image_url:
            data['payload']["inputImageUrl"] = input_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity

        if excluded_areas:
            data["payload"]["excludedAreas"] = json.dumps(excluded_areas)
        if noise_filter:
            data["payload"]["noiseFilter"] = noise_filter

        return requests.post(f"{data['base_uri']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @classmethod
    def flex_compare(cls, execution_id, test_name, baseline_image=None, baseline_image_url=None, input_image=None,
                     input_image_url=None, min_similarity=None, excluded_areas=None):
        """
            Compare the baselineImage with the inputImage and generate a resultImage highlighting the differences if any were found.
            The images may have different dimensions. For further information, view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str baseline_image: Path to baseline image to compare with the input image.
            :param str baseline_image_url: Baseline image to compare with the input image from URL.
            :param str input_image: Path to input image to be compared with the baselineImage.
            :param str input_image_url: Input image to be compared with the baselineImage from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :param list excluded_areas: Areas to be ignored when comparing the images.
                                        These areas are defined on the baseline image.
            :return: The API Response object.
            :rtype: Response
        """
        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/flex-compare", execution_id,
                                test_name)

        data["files"] = []
        if baseline_image:
            data["files"].append(('baselineImage', (cls.get_input_name(baseline_image), open(
                baseline_image,
                'rb'), mimetypes.guess_type(input_image)[0])))

        if baseline_image_url:
            data['payload']["baselineImageUrl"] = baseline_image_url

        if input_image:
            data["files"].append(('inputImage', (cls.get_input_name(input_image), open(
                input_image,
                'rb'), mimetypes.guess_type(input_image)[0])))

        if input_image_url:
            data['payload']["inputImageUrl"] = input_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity
        if excluded_areas:
            data["payload"]["excludedAreas"] = json.dumps(excluded_areas)

        return requests.post(f"{data['base_uri']}:{data['port']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @classmethod
    def search(cls, execution_id, test_name, parent_image=None, parent_image_url=None, child_image_url=None,
               child_image=None, min_similarity='70'):
        """
            Search a child image within a parent image. Child image must have the same size as in parent image to be found.
             For further information view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str parent_image: Path to the image containing the child images.
            :param str parent_image_url: The image containing the child images from URL.
            :param str child_image: Path to the image to be located within the parent image.
            :param str child_image_url: The image to be located within the parent image from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :return: The API Response object.
            :rtype: Response
        """
        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/search", execution_id,
                                test_name)

        data["files"] = []
        if parent_image:
            data["files"].append(('parentImage', (cls.get_input_name(parent_image), open(
                parent_image,
                'rb'), mimetypes.guess_type(parent_image)[0])))

        if parent_image_url:
            data['payload']["parentImageUrl"] = parent_image_url

        if child_image:
            data["files"].append(('childImage', (cls.get_input_name(child_image), open(
                child_image,
                'rb'), mimetypes.guess_type(child_image)[0])))

        if child_image_url:
            data['payload']["childImageUrl"] = child_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity

        return requests.post(f"{data['base_uri']}:{data['port']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @classmethod
    def flex_search(cls, execution_id, test_name, parent_image=None, parent_image_url=None, child_image_url=None,
                    child_image=None, min_similarity=None):
        """
            Search a child image within a parent image using the flex search algorithm. This allows to find the child image
            even if the size is not the same as in the parent image. For further information, view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str parent_image: Path to the image containing the child images.
            :param str parent_image_url: The image containing the child images from URL.
            :param str child_image: Path to the image to be located within the parent image.
            :param str child_image_url: The image to be located within the parent image from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :return: The API Response object.
            :rtype: Response
        """
        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/flex-search", execution_id,
                                test_name)
        data["files"] = []
        if parent_image:
            data["files"].append(('parentImage', (cls.get_input_name(parent_image), open(
                parent_image,
                'rb'), mimetypes.guess_type(parent_image)[0])))

        if parent_image_url:
            data['payload']["parentImageUrl"] = parent_image_url

        if child_image:
            data["files"].append(('childImage', (cls.get_input_name(child_image), open(
                child_image,
                'rb'), mimetypes.guess_type(child_image)[0])))

        if child_image_url:
            data['payload']["childImageUrl"] = child_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity

        return requests.post(f"{data['base_uri']}:{data['port']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @classmethod
    def locate(cls, execution_id, test_name, container_image=None, container_image_url=None, main_image=None,
               main_image_url=None, relative_image=None, relative_image_url=None, min_similarity='70'):
        """
            Locate the relative position of the relative image regarding to mainImage inside the container image.
            For further information, view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str container_image: Path to the image containing the searched images.
            :param str container_image_url: The image containing the searched images from URL.
            :param str main_image: Path to the image to be located in the container and used as a reference point for the relative image.
            :param str main_image_url: The image to be located in the container and used as a reference point for the relative image from URL.
            :param str relative_image: Path to the image to be located in the container and give it's relative position to main image.
            :param str relative_image_url: The image to be located in the container and give it's relative position to mainImage from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :return: The API Response object.
            :rtype: Response
        """

        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/locate", execution_id,
                                test_name)
        data["files"] = []
        if container_image:
            data["files"].append(('containerImage', (cls.get_input_name(container_image), open(
                container_image,
                'rb'), mimetypes.guess_type(container_image)[0])))

        if container_image_url:
            data['payload']["containerImageUrl"] = container_image_url

        if main_image:
            data["files"].append(('mainImage', (cls.get_input_name(main_image), open(
                main_image,
                'rb'), mimetypes.guess_type(main_image)[0])))

        if main_image_url:
            data['payload']["mainImageUrl"] = main_image_url

        if relative_image:
            data["files"].append(('relativeImage', (cls.get_input_name(relative_image), open(
                relative_image,
                'rb'), mimetypes.guess_type(relative_image)[0])))

        if relative_image_url:
            data['payload']["relativeImageUrl"] = relative_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity

        return requests.post(f"{data['base_uri']}:{data['port']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @classmethod
    def flex_locate(cls, execution_id, test_name, container_image=None, container_image_url=None, main_image=None,
                    main_image_url=None, relative_image=None, relative_image_url=None, min_similarity=None):
        """
            Locate the relative position of the relative image regarding to main image inside the containerImage using the flex locate algorithm.
            This allows to find the child image even if the size is not the same as in the parent image.
            For further information, view Swagger.

            :param str execution_id: Execution to which this test belongs.
            :param str test_name: The name of this test.
            :param str container_image: Path to the image containing the searched images.
            :param str container_image_url: The image containing the searched images from URL.
            :param str main_image: Path to the image to be located in the container and used as a reference point for the relative image.
            :param str main_image_url: The image to be located in the container and used as a reference point for the relative image from URL.
            :param str relative_image: Path to the image to be located in the container and give it's relative position to main image.
            :param str relative_image_url: The image to be located in the container and give it's relative position to mainImage from URL.
            :param str min_similarity: Minimum similarity to determine if a test passes or not.
                                         If None, the status will be Undefined.
            :return: The API Response object.
            :rtype: Response
        """
        data = cls.base_request(cls.get_magnifai_api_port(), "/aut-magnifai-api/flex-locate", execution_id,
                                test_name)
        data["files"] = []
        if container_image:
            data["files"].append(('containerImage', (cls.get_input_name(container_image), open(
                container_image,
                'rb'), mimetypes.guess_type(container_image)[0])))

        if container_image_url:
            data['payload']["containerImageUrl"] = container_image_url

        if main_image:
            data["files"].append(('mainImage', (cls.get_input_name(main_image), open(
                main_image,
                'rb'), mimetypes.guess_type(main_image)[0])))

        if main_image_url:
            data['payload']["mainImageUrl"] = main_image_url

        if relative_image:
            data["files"].append(('relativeImage', (cls.get_input_name(relative_image), open(
                relative_image,
                'rb'), mimetypes.guess_type(relative_image)[0])))

        if relative_image_url:
            data['payload']["relativeImageUrl"] = relative_image_url

        if min_similarity:
            data["payload"]["minSimilarity"] = min_similarity

        return requests.post(f"{data['base_uri']}:{data['port']}{data['path']}",
                             headers={'Authorization': f'Bearer {data["auth"]}'},
                             data=data['payload'],
                             files=data["files"])

    @staticmethod
    def get_mime_type(file_path):
        mime_type, _ = mimetypes.guess_type(file_path)
        return mime_type

    @classmethod
    def get_content_type(cls, baseline_image_url):
        try:
            address = urllib.request.urlopen(baseline_image_url)
            return address.getheader('Content-Type')
        except Exception as e:
            return None

    @classmethod
    def get_magnifai_api_port(cls):
        return int(
            AutProperties.get_property(Property.MAGNIFAIAPI_PORT) or AutProperties.get_property(Property.MAGNIFAI_PORT))

    @classmethod
    def get_input_name(cls, input):
        return input.split('/')[-1]



import time
from datetime import datetime

import requests

from magnifai_aut_sdk.aut_properties import AutProperties, Property


class AutAuth:
    accessTokenExpirationTimestamp = 0
    refreshTokenExpirationTimestamp = 0
    accessToken = None
    tokenUser = ""
    refreshToken = None
    ENDPOINT = "/realms/aut/protocol/openid-connect/token"
    CLIENT_ID = "aut-magnifai-aut-magnifai_aut_sdk-python"
    PASSWORD_GRANT_TYPE = "password"
    REFRESH_TOKEN_GRANT_TYPE = "refresh_token"

    def __init__(self):
        raise ValueError("Utility class")

    @classmethod
    def is_token_expired(cls, expiration_time):
        now = int(time.mktime(datetime.now().timetuple()) * 1000)
        return now > expiration_time - cls.get_threshold_millis()

    @classmethod
    def get_threshold_millis(cls):
        return int(AutProperties.get_property(Property.AUTH_TOKEN_THRESHOLD_SECONDS)) * 1000

    @classmethod
    def get_token(cls):
        if cls.tokenUser != AutProperties.get_property(Property.AUTH_USER):
            return cls.req_token()
        elif not cls.is_token_expired(cls.accessTokenExpirationTimestamp):
            return cls.accessToken
        elif not cls.is_token_expired(cls.refreshTokenExpirationTimestamp):
            return cls.refreshToken()
        else:
            return cls.req_token()

    @classmethod
    def req_token(cls):
        response = requests.post(
            f"{AutProperties.get_property(Property.MAGNIFAI_AUTH_HOST)}{cls.ENDPOINT}",
            headers={"Content-Type": "application/x-www-form-urlencoded"},
            data={
                "client_id": cls.CLIENT_ID,
                "username": AutProperties.get_property(Property.AUTH_USER),
                "password": AutProperties.get_property(Property.AUTH_PASSWORD),
                "grant_type": cls.PASSWORD_GRANT_TYPE
            }
        )
        cls.assign_values(response)
        cls.tokenUser = AutProperties.get_property(Property.AUTH_USER)
        return cls.accessToken

    @classmethod
    def refresh_token(cls):
        response = cls.token_endpoint_specification().post(
            data={
                "refresh_token": cls.refreshToken,
                "grant_type": cls.REFRESH_TOKEN_GRANT_TYPE
            }
        )
        cls.assign_values(response)
        return cls.accessToken

    @classmethod
    def token_endpoint_specification(cls):
        port = int(AutProperties.get_property(Property.AUTH_PORT) if AutProperties.get_property(
            Property.AUTH_PORT) else AutProperties.get_property(
            Property.MAGNIFAI_PORT))
        return requests.Session().post(
            f"{AutProperties.get_property(Property.MAGNIFAI_HOST)}{cls.ENDPOINT}",
            headers={"Content-Type": "application/x-www-form-urlencoded"},
            data={
                "client_id": cls.CLIENT_ID
            }
        )

    @classmethod
    def assign_values(cls, response):
        now = int(time.mktime(datetime.now().timetuple()) * 1000)
        data = response.json()
        cls.accessToken = data["access_token"]
        cls.refreshToken = data["refresh_token"]
        cls.accessTokenExpirationTimestamp = now + data["expires_in"] * 1000
        cls.refreshTokenExpirationTimestamp = now + data["refresh_expires_in"] * 1000



from setuptools import setup, find_packages

setup(
    name='magnifai-aut-magnifai-aut-magnifai_aut_sdk-python-python',
    version='0.0.3',
    packages=['magnifai_aut_sdk'],
    install_requires=[
        'iniconfig==2.0.0',
        'jsonpath==0.82.2',
        'pytest==7.4.1',
        'requests==2.31.0',
        'urllib3==2.0.4',
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.9',
    url='https://github.com/magnifai-gbx/aut-sdk-python',
    author='alejandro.rm',
    author_email='alejandro.rm@globant.com',
    description='Aut magnifai SDK'
)
